==> nextcloud-29.0.15.tar.bz2: nextcloud/apps/activity/l10n/uz.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Shaxsiy faoliyat tasmasi uchun %s",
    "Your feed URL is invalid" : "Tasma URL manzili yaroqsiz",
    "Activity feed for %1$s" : " %1$s uchun faoliyat tasmasi",
    "Activity feed" : "Faoliyat tasmasi",
    "Your settings have been updated." : "Sozlamalaringiz yangilandi.",
    "Settings have been updated." : "Sozlamalar yangilandi.",
    "Recent activity" : "Oxirgi faollik",
    "No activities" : "Hech qanday faollik yo'q",
    "More activities" : "Ko`proq faollik",
    "Daily activity summary for %s" : " %s uchun kundalik faoliyat xulosasi",
    "_and %n more…_::_and %n more…_" : ["va %n dan ko`proq..."],
    "All activities" : "Barcha faolliklar",
    "By others" : "Boshqalar uchun",
    "By you" : "Siz uchun",
    "Activity at %s" : " %s faollikda",
    "Hello %s" : "Xush kelibsiz %s",
    "Hello %s," : "Xush kelibsiz %s,",
    "There was some activity at %s" : "Biroz  %s faollik bor edi",
    "_and %n more _::_and %n more _" : ["va %n dan ko`p"],
    "Mail" : "Xabar",
    "Push" : "Surish",
    "Activity" : "Faollik",
    "Notifications" : "Bildirishnomalar",
    "This application enables people to view a log of activities about them, their files or other data." : "Ushbu ilova odamlarga ularning faolliklari jurnalini, ularning fayllari yoki boshqa ma'lumotlarni ko'rish imkonini beradi.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Bu ilova foydalanuvchilarga Nextcloud’da oʻz fayllari va maʼlumotlari bilan bogʻliq amallarni koʻrish imkonini beradi.\n\t\tHar bir kishi shaxsiy sozlamalarida o'zining individual faollik sozlamalarini sozlashi mumkin,\n\t\tE-pochta orqali yuboriladigan mobil telefonlarga qaysi faollikni o'tkazish kerakligini tanlash uchun\n\t\tyoki har kuni ertalab kundalik xulosa yuboriladimi.\n\t\tBatafsil ma'lumot Faollik hujjatlarida mavjud.",
    "Send email" : "Xabar yuborish",
    "Send push notification" : "Push-bildirishnoma yuborish",
    "Activity notification configuration" : "Faolliklar bildirishnomalari konfiguratsiyasi",
    "Today" : "Bugun",
    "Yesterday" : "Kecha",
    "You need to set up your email address before you can receive notification emails." : "E-pochta xabarnomalarini olishdan oldin elektron pochta manzilingizni sozlashingiz kerak.",
    "Send activity emails" : "Faoliyat xatlarini yuboring",
    "As soon as possible" : "Iloji boricha tez",
    "Hourly" : "Soatlik",
    "Daily" : "Kunlik",
    "Weekly" : "Haftalik",
    "You commented" : "Siz fikr bildirgansiz",
    "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
    "Open {filename}" : "Ochiq {filename}",
    "in {path}" : " {path} da",
    "Home" : "Uy",
    "Could not load activities" : "Faollikni yuklab bo‘lmadi",
    "Loading activities" : "Faolliklar yuklanmoqda",
    "This stream will show events like additions, changes & shares" : "Bu oqim qoʻshimchalar, oʻzgartirishlar va ulashishlar kabi voqealarni koʻrsatadi",
    "No activity yet" : "Afsuski, faollik mavjud emas",
    "Loading more activities" : "Ko`proq faollik yuklanmoqda",
    "No more activities." : "Boshqa faollik mavjud emas",
    "Could not enable RSS link" : "RSS havolasini yoqib bo‘lmadi",
    "RSS link copied to clipboard" : "RSS havolasi vaqtinchalik xotiraga nusxalandi",
    "Could not copy the RSS link, please copy manually:" : "RSS havolasini nusxalab boʻlmadi, qoʻlda nusxa koʻchiring:",
    "Activity settings" : "Faollik sozzlamalari",
    "Enable RSS feed" : "RSS tasmasini yoqish",
    "RSS feed" : "RSS tasmasi",
    "Copy RSS feed link" : "RSS tasma havolasidan nusxa oling",
    "Personal notification settings" : "Shaxsiy bildirishnoma sozlamalari",
    "Unable to load the activity list" : "Faolliklar roʻyxatini yuklab boʻlmadi",
    "Choose for which activities you want to get an email or push notification." : "Qaysi faolliklar uchun elektron pochta yoki push-bildirishnoma olishni xohlayotganingizni tanlang.",
    "Choose for which activities you want to get a push notification." : "Qaysi faolliklar uchun push-bildirishnoma olishni xohlayotganingizni tanlang.",
    "Notification" : "Bildirishnomalar",
    "Enable notification emails" : "Email xabarnomalarini yoqish",
    "Daily activity summary" : "Kundalik faollik xulosasi",
    "Send daily activity summary in the morning" : "Har ertalab kundalik faollik xulosasini yuboring",
    "Default settings" : "Standart sozlamalar",
    "Configure the default notification settings for new accounts." : "Yangi akkauntlar uchun standart bildirishnoma sozlamalarini sozlang.",
    "Unable to save the settings" : "Sozlamalarni saqlab bo‘lmadi",
    "No more events to load" : "Yuklanadigan boshqa tadbirlar yo‘q"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/activity/l10n/uz.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Shaxsiy faoliyat tasmasi uchun %s",
    "Your feed URL is invalid" : "Tasma URL manzili yaroqsiz",
    "Activity feed for %1$s" : " %1$s uchun faoliyat tasmasi",
    "Activity feed" : "Faoliyat tasmasi",
    "Your settings have been updated." : "Sozlamalaringiz yangilandi.",
    "Settings have been updated." : "Sozlamalar yangilandi.",
    "remote user" : "masofaviy foydalanuvchi",
    "Recent activity" : "Oxirgi faollik",
    "No activities" : "Hech qanday faollik yo'q",
    "More activities" : "Ko`proq faollik",
    "Daily activity summary for %s" : " %s uchun kundalik faoliyat xulosasi",
    "_and %n more…_::_and %n more…_" : ["va %n dan ko`proq..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Siz <a href=\"%s\">sozlamalarida</a>da kundalik dayjest e-pochtalarini o'chirib qo'yishingiz mumkin.",
    "You can disable daily digest emails in the settings: %s" : "Sozlamalarda kundalik dayjest e-pochtalarini o‘chirib qo‘yishingiz mumkin: %s",
    "All activities" : "Barcha faolliklar",
    "By others" : "Boshqalar uchun",
    "By you" : "Siz uchun",
    "Activity at %s" : " %s faollikda",
    "Hello %s" : "Xush kelibsiz %s",
    "Hello %s," : "Xush kelibsiz %s,",
    "There was some activity at %s" : "Biroz  %s faollik bor edi",
    "_and %n more _::_and %n more _" : ["va %n dan ko`p"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Siz ushbu xatlarning chastotasini o'zgartirishingiz yoki ularni  <a href=\"%s\">sozlamalaridan</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Siz ushbu elektron pochta xabarlarining chastotasini o'zgartirishingiz yoki sozlamalarda ularni o'chirib qo'yishingiz mumkin: %s",
    "Mail" : "Xabar",
    "Push" : "Surish",
    "Activity" : "Faollik",
    "Notifications" : "Bildirishnomalar",
    "This application enables people to view a log of activities about them, their files or other data." : "Ushbu ilova odamlarga ularning faolliklari jurnalini, ularning fayllari yoki boshqa ma'lumotlarni ko'rish imkonini beradi.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Bu ilova foydalanuvchilarga Nextcloud’da oʻz fayllari va maʼlumotlari bilan bogʻliq amallarni koʻrish imkonini beradi.\n\t\tHar bir kishi shaxsiy sozlamalarida o'zining individual faollik sozlamalarini sozlashi mumkin,\n\t\tE-pochta orqali yuboriladigan mobil telefonlarga qaysi faollikni o'tkazish kerakligini tanlash uchun\n\t\tyoki har kuni ertalab kundalik xulosa yuboriladimi.\n\t\tBatafsil ma'lumot Faollik hujjatlarida mavjud.",
    "Send email" : "Xabar yuborish",
    "Send push notification" : "Push-bildirishnoma yuborish",
    "Activity notification configuration" : "Faolliklar bildirishnomalari konfiguratsiyasi",
    "Today" : "Bugun",
    "Yesterday" : "Kecha",
    "You need to set up your email address before you can receive notification emails." : "E-pochta xabarnomalarini olishdan oldin elektron pochta manzilingizni sozlashingiz kerak.",
    "Send activity emails" : "Faoliyat xatlarini yuboring",
    "As soon as possible" : "Iloji boricha tez",
    "Hourly" : "Soatlik",
    "Daily" : "Kunlik",
    "Weekly" : "Haftalik",
    "You commented" : "Siz fikr bildirgansiz",
    "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
    "Open {filename}" : "Ochiq {filename}",
    "in {path}" : " {path} da",
    "Home" : "Uy",
    "Could not load activities" : "Faollikni yuklab bo‘lmadi",
    "Loading activities" : "Faolliklar yuklanmoqda",
    "This stream will show events like additions, changes & shares" : "Bu oqim qoʻshimchalar, oʻzgartirishlar va ulashishlar kabi voqealarni koʻrsatadi",
    "No activity yet" : "Afsuski, faollik mavjud emas",
    "Loading more activities" : "Ko`proq faollik yuklanmoqda",
    "No more activities." : "Boshqa faollik mavjud emas",
    "Could not enable RSS link" : "RSS havolasini yoqib bo‘lmadi",
    "RSS link copied to clipboard" : "RSS havolasi vaqtinchalik xotiraga nusxalandi",
    "Could not copy the RSS link, please copy manually:" : "RSS havolasini nusxalab boʻlmadi, qoʻlda nusxa koʻchiring:",
    "Activity settings" : "Faollik sozzlamalari",
    "Enable RSS feed" : "RSS tasmasini yoqish",
    "RSS feed" : "RSS tasmasi",
    "Copy RSS feed link" : "RSS tasma havolasidan nusxa oling",
    "Personal notification settings" : "Shaxsiy bildirishnoma sozlamalari",
    "Unable to load the activity list" : "Faolliklar roʻyxatini yuklab boʻlmadi",
    "Choose for which activities you want to get an email or push notification." : "Qaysi faolliklar uchun elektron pochta yoki push-bildirishnoma olishni xohlayotganingizni tanlang.",
    "Choose for which activities you want to get a push notification." : "Qaysi faolliklar uchun push-bildirishnoma olishni xohlayotganingizni tanlang.",
    "Notification" : "Bildirishnomalar",
    "Enable notification emails" : "Email xabarnomalarini yoqish",
    "Daily activity summary" : "Kundalik faollik xulosasi",
    "Send daily activity summary in the morning" : "Har ertalab kundalik faollik xulosasini yuboring",
    "Default settings" : "Standart sozlamalar",
    "Configure the default notification settings for new accounts." : "Yangi akkauntlar uchun standart bildirishnoma sozlamalarini sozlang.",
    "Unable to save the settings" : "Sozlamalarni saqlab bo‘lmadi",
    "No more events to load" : "Yuklanadigan boshqa tadbirlar yo‘q"
},
"nplurals=1; plural=0;");
